@@ -263,7 +263,10 @@ def main(return_result=False):
                 '\nUsing --deployv option you will need to run the following extra step '
                 'manually after to create the container or after running 20-run.sh script'
             )
-            stdout.write('\ndocker exec -it --user=root CONTAINER chown -R odoo:odoo /home/odoo/.ssh\n')
+            stdout.write(
+                '\ndocker exec -it --user=root CONTAINER '
+                'find /home/odoo -maxdepth 1 -not -user odoo -exec chown -R odoo:odoo {} \\;\n'
+            )
             if not default_docker_image:
                 # TODO: Add the URL to open the pipelines
                 stdout.write(
